# pastasoss

Predicting Accurate Spectral Traces in Astrophysical SOSS Spectra

By: Tyler Baines, STScI Science Support Analyst (NIRISS/SOSS Team) email: tbaines@stsci.edu

STATUS: Work In Progress - 05/2023
- Solving some minors bugs resulting the package failing to import in a juypter notebook. Should be resolved soon.

A very short demo notebook is included with the package and we encourage users to checkout. 

This tool is capable of predicting the spectral trace positions in a NIRISS SOSS observations with the GR700XD at given a pupil wheel position with sub-pixel accuracy. The tool currently supports spectral order 1 and 2, with future support for order 3. In addition, future updates will include both spectral traces poisition and their associated wavelengths. 

As more and more JWST NIRISS/SOSS data becomes available we plan on updating the tool and reference data files. 

Community feedback  and contribution is encouraged! 

